import React, { useState, useCallback, useEffect } from 'react';
import Highlight, { defaultProps } from 'prism-react-renderer';
import copy from 'copy-to-clipboard';
import theme from 'prism-react-renderer/themes/nightOwl';

// @ts-nocheck
var highlightAddStart = false;
var highlightRemoveStart = false; // const highlightClassName = "gatsby-highlight-code-line";

var highlightAddClassName = "bg-highlight-add";
var highlightRemoveClassName = "bg-highlight-remove";
var highlightLineClassName = "bg-highlight-line";

function useClipboard(text, timeout) {
  if (timeout === void 0) {
    timeout = 1500;
  }

  var _useState = useState(false),
      hasCopied = _useState[0],
      setHasCopied = _useState[1];

  var onCopy = useCallback(function () {
    var didCopy = copy(text);
    setHasCopied(didCopy);
  }, [text]);
  useEffect(function () {
    if (hasCopied) {
      var id = setTimeout(function () {
        setHasCopied(false);
      }, timeout);
      return function () {
        return clearTimeout(id);
      };
    }
  }, [timeout, hasCopied]);
  return {
    value: text,
    onCopy: onCopy,
    hasCopied: hasCopied
  };
}

var highlightLine = function highlightLine(lineArray, lineProps) {
  var shouldExclude = false;
  lineArray.forEach(function (line) {
    var content = line.content; // Highlight lines with "// highlight-line"

    if (content.replace(/\s/g, "").includes("//highlight-line")) {
      lineProps.className = lineProps.className + " " + highlightLineClassName;
      line.content = content.replace("// highlight-line", "").replace("//highlight-line", "");
    } // Stop highlighting


    if (!!highlightAddStart && content.replace(/\s/g, "") === "//highlight-add-end") {
      highlightAddStart = false;
      shouldExclude = true;
    }

    if (!!highlightRemoveStart && content.replace(/\s/g, "") === "//highlight-remove-end") {
      highlightRemoveStart = false;
      shouldExclude = true;
    } // Start highlighting after "//highlight-start"


    if (content.replace(/\s/g, "") === "//highlight-add-start") {
      highlightAddStart = true;
      shouldExclude = true;
    }

    if (content.replace(/\s/g, "") === "//highlight-remove-start") {
      highlightRemoveStart = true;
      shouldExclude = true;
    }
  }); // Highlight lines between //highlight-start & //highlight-end

  if (highlightAddStart) {
    lineProps.className = lineProps.className + " " + highlightAddClassName;
  }

  if (highlightRemoveStart) {
    lineProps.className = lineProps.className + " " + highlightRemoveClassName;
  }

  return {
    shouldExclude: shouldExclude,
    highlightAddStart: highlightAddStart,
    highlightRemoveStart: highlightRemoveStart
  };
};

var CodeBlock = function CodeBlock(_ref) {
  var code = _ref.code,
      lang = _ref.lang;

  // const matches = children.props.className.match(/language-(?<lang>.*)/);
  var _useClipboard = useClipboard(code),
      hasCopied = _useClipboard.hasCopied,
      onCopy = _useClipboard.onCopy;

  return React.createElement(Highlight, Object.assign({}, defaultProps, {
    code: code,
    theme: theme,
    language: lang
  }), function (_ref2) {
    var className = _ref2.className,
        style = _ref2.style,
        tokens = _ref2.tokens,
        getLineProps = _ref2.getLineProps,
        getTokenProps = _ref2.getTokenProps;
    return React.createElement("pre", {
      className: className + " sl-highlight-pre relative",
      style: style
    }, React.createElement("div", {
      className: "flex absolute -mx-2 top-0 right-0 p-2"
    }, React.createElement("div", {
      className: "px-2"
    }, React.createElement("button", {
      type: "button",
      onClick: onCopy,
      className: "sl-highlight-lang flex items-center transition-all hover:bg-gray-800 rounded-md px-3 py-1 text-sm sm:text-base uppercase p-2 font-semibold"
    }, React.createElement("svg", {
      xmlns: "http://www.w3.org/2000/svg",
      width: "16",
      height: "16",
      fill: "currentColor",
      "class": "bi bi-clipboard-check",
      viewBox: "0 0 16 16"
    }, hasCopied ? React.createElement("path", {
      "fill-rule": "evenodd",
      d: "M10.854 7.146a.5.5 0 0 1 0 .708l-3 3a.5.5 0 0 1-.708 0l-1.5-1.5a.5.5 0 1 1 .708-.708L7.5 9.793l2.646-2.647a.5.5 0 0 1 .708 0z"
    }) : null, React.createElement("path", {
      d: "M4 1.5H3a2 2 0 0 0-2 2V14a2 2 0 0 0 2 2h10a2 2 0 0 0 2-2V3.5a2 2 0 0 0-2-2h-1v1h1a1 1 0 0 1 1 1V14a1 1 0 0 1-1 1H3a1 1 0 0 1-1-1V3.5a1 1 0 0 1 1-1h1v-1z"
    }), React.createElement("path", {
      d: "M9.5 1a.5.5 0 0 1 .5.5v1a.5.5 0 0 1-.5.5h-3a.5.5 0 0 1-.5-.5v-1a.5.5 0 0 1 .5-.5h3zm-3-1A1.5 1.5 0 0 0 5 1.5v1A1.5 1.5 0 0 0 6.5 4h3A1.5 1.5 0 0 0 11 2.5v-1A1.5 1.5 0 0 0 9.5 0h-3z"
    })), React.createElement("span", {
      className: "ml-2"
    }, hasCopied ? "Copied" : "Copy"))), React.createElement("div", {
      className: "px-2"
    }, React.createElement("div", {
      className: "sl-highlight-lang text-sm sm:text-base pr-3 py-1 uppercase font-semibold"
    }, React.createElement("span", null, lang)))), tokens.map(function (line, i) {
      // if (!line[0].empty) {
      var lineProps = getLineProps({
        line: line,
        key: i
      });

      var _highlightLine = highlightLine(line, lineProps),
          shouldExclude = _highlightLine.shouldExclude,
          highlightAddStart = _highlightLine.highlightAddStart,
          highlightRemoveStart = _highlightLine.highlightRemoveStart;

      return !shouldExclude ? React.createElement("div", Object.assign({
        key: i
      }, lineProps), highlightAddStart ? React.createElement("span", {
        className: "sl-highlight-add"
      }, "+") : null, highlightRemoveStart ? React.createElement("span", {
        className: "sl-highlight-remove"
      }, "-") : null, line.map(function (token, key) {
        return React.createElement("span", Object.assign({
          key: key
        }, getTokenProps({
          token: token,
          key: key
        })));
      })) : null; // }
    }));
  });
};

export default CodeBlock;
//# sourceMappingURL=highlight.esm.js.map
